jarust_core

Trait GenerateTransaction

pub trait GenerateTransaction:
    Send
    + Sync
    + Debug
    + 'static {
    // Required method
    fn generate_transaction(&self) -> String;
}
GenerateTransaction can be provided to an interface for generating messages transactions.

The more they’re unique the better, especially when choosing with WebSockets interface as demultiplexing heavily relies on transaction ids.

Required Methods

Implementors